Scrapinghub command line client
===============================

``shub`` is a tool used to manage Scrapinghub services from the command line.

Installation
------------

Install with::

    pip install shub

Usage
-----

Get help with::

    shub

Documentation
-------------

Documentation is available here:
http://doc.scrapinghub.com/shub.html
